/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.osgi.web.wab.extender.internal.adapter;

import java.io.IOException;

import java.util.Enumeration;

import javax.servlet.Servlet;
import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

/**
 * @author Raymond Augé
 */
public class ServletExceptionAdapter implements Servlet {

	public ServletExceptionAdapter(
		Servlet servlet, ModifiableServletContext modifiableServletContext) {

		_servlet = servlet;
		_modifiableServletContext = modifiableServletContext;
	}

	@Override
	public void destroy() {
		_servlet.destroy();
	}

	public Exception getException() {
		return _exception;
	}

	@Override
	public ServletConfig getServletConfig() {
		return _servlet.getServletConfig();
	}

	@Override
	public String getServletInfo() {
		return _servlet.getServletInfo();
	}

	@Override
	public void init(final ServletConfig servletConfig) {
		try {
			_servlet.init(
				new ServletConfigWrapper(
					servletConfig, _modifiableServletContext));
		}
		catch (Exception e) {
			_exception = e;
		}
	}

	@Override
	public void service(
			ServletRequest servletRequest, ServletResponse servletResponse)
		throws IOException, ServletException {

		_servlet.service(servletRequest, servletResponse);
	}

	private Exception _exception;
	private ModifiableServletContext _modifiableServletContext;
	private final Servlet _servlet;

	private static class ServletConfigWrapper implements ServletConfig {

		public ServletConfigWrapper(
			ServletConfig wrappedServletConfig,
			ModifiableServletContext modifiableServletContext) {

			_wrappedServletConfig = wrappedServletConfig;
			_modifiableServletContext = modifiableServletContext;
		}

		public String getInitParameter(String name) {
			return _wrappedServletConfig.getInitParameter(name);
		}

		public Enumeration getInitParameterNames() {
			return _wrappedServletConfig.getInitParameterNames();
		}

		public ServletContext getServletContext() {
			return (ServletContext)_modifiableServletContext;
		}

		public String getServletName() {
			return _wrappedServletConfig.getServletName();
		}

		private ModifiableServletContext _modifiableServletContext;
		private final ServletConfig _wrappedServletConfig;

	}

}